# Copyright (c) 2020 IBM Corp. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Common IBM constants."""

# IBM Cloud token retrieval URL
IAM_TOKEN_URL = "https://iam.cloud.ibm.com/identity/token"  # nosec B105

# IAM token API KEY grant type
IAM_API_KEY_GRANT_TYPE = "urn:ibm:params:oauth:grant-type:apikey"

# IBM Cloud containers API base URL
IC_CONTAINERS_BASE_URL = "https://containers.cloud.ibm.com"
